Verifier

Type Alias Verifier 

pub type Verifier = fn(prog: &[u8]) -> Result<(), Error>;
eBPF verification function that returns an error if the program does not meet its requirements.

Some examples of things the verifier may reject the program for:

  • Program does not terminate.
  • Unknown instructions.
  • Bad formed instruction.
  • Unknown eBPF helper index.